===========
trame-video
===========

Trame wrapper to vue @videothing components

License
-------

Free software: MIT License


Installing
----------

Install the application

.. code-block:: console

    pip install -e .

or

.. code-block:: console

    pip install trame-video
